@@ -3,17 +3,17 @@
 #include <dejagnu.h>
 
 void
-api_process (dwg_object * obj)
+api_process (dwg_object *obj)
 {
   int error;
-  BITCODE_BL i, num_databytes, num_eed, num_objid_handles;
+  BITCODE_BL i, num_databytes, num_xdata, num_objid_handles;
   BITCODE_BS cloning_flags;
-  dwg_object_ref* parent;
+  dwg_object_ref *parent;
 
   dwg_obj_xrecord *xrecord = dwg_object_to_XRECORD (obj);
 
   num_databytes = dwg_obj_xrecord_get_num_databytes (xrecord, &error);
-  if (!error  && num_databytes == xrecord->num_databytes)
+  if (!error && num_databytes == xrecord->num_databytes)
     pass ("Working Properly");
   else
     fail ("error in reading num_databytes");
@@ -24,14 +24,14 @@ api_process (dwg_object * obj)
   else
     fail ("error in reading cloning_flags");
 
-  num_eed = dwg_obj_xrecord_get_num_eed (xrecord, &error);
-  if (!error && num_eed == xrecord->num_eed)
+  num_xdata = dwg_obj_xrecord_get_num_xdata (xrecord, &error);
+  if (!error && num_xdata == xrecord->num_xdata)
     pass ("Working Properly");
   else
-    fail ("error in reading num_eed");
+    fail ("error in reading num_xdata");
 
 #if 0
-  for (i=0; i<num_eed; i++)
+  for (i=0; i<num_xdata; i++)
     {
       Dwg_Eed *eed = dwg_obj_xrecord_get_eed (xrecord, i, &error);
       if (!error && eed[0] == xrecord->eed[i])
@@ -50,15 +50,14 @@ api_process (dwg_object * obj)
 #endif
 
   num_objid_handles = dwg_obj_xrecord_get_num_objid_handles (xrecord, &error);
-  if (!error  && num_objid_handles == xrecord->num_objid_handles)
+  if (!error && num_objid_handles == xrecord->num_objid_handles)
     pass ("Working Properly");
   else
     fail ("error in reading num_objid_handles");
 
-  parent = dwg_obj_xrecord_get_parenthandle (xrecord, &error);
-  if (!error  && parent == xrecord->parenthandle)
+  parent = dwg_obj_xrecord_get_ownerhandle (xrecord, &error);
+  if (!error && parent == xrecord->ownerhandle)
     pass ("Working Properly");
   else
-    fail ("error in reading parenthandle");
-
+    fail ("error in reading ownerhandle");
 }
