@@ -27,7 +27,6 @@
 #include <libxml/parser.h>
 #include "common.c"
 
-
 // entities to check against:
 // perl -lne'/type="(IAcad.*?)" / and print $1' test/test-data/*/*.xml|sort -u
 /*
@@ -47,8 +46,8 @@
  */
 int load_dwg (char *dwgfilename, xmlNodePtr rootnode);
 void common_entity_attrs (xmlNodePtr node, const Dwg_Object *obj);
-void add_2dpolyline (xmlNodePtr rootnode, const Dwg_Object* obj);
-void add_3dpolyline (xmlNodePtr rootnode, const Dwg_Object* obj);
+void add_2dpolyline (xmlNodePtr rootnode, const Dwg_Object *obj);
+void add_3dpolyline (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_arc (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_block (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_circle (xmlNodePtr rootnode, const Dwg_Object *obj);
@@ -56,7 +55,7 @@ void add_ellipse (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_helix (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_insert (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_line (xmlNodePtr rootnode, const Dwg_Object *obj);
-void add_lwpolyline (xmlNodePtr rootnode, const Dwg_Object* obj);
+void add_lwpolyline (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_mline (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_point (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_ray (xmlNodePtr rootnode, const Dwg_Object *obj);
@@ -65,12 +64,17 @@ void add_table (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_text (xmlNodePtr rootnode, const Dwg_Object *obj);
 void add_xline (xmlNodePtr rootnode, const Dwg_Object *obj);
 
-#define newXMLProp(name,buf) xmlNewProp(node, (const xmlChar *)name, buf); free(buf)
-#define newXMLcProp(name,buf) xmlNewProp(node, (const xmlChar *)name, (xmlChar*)(buf))
-#define newXMLEntity(rootnode) xmlNewChild (rootnode, NULL, (const xmlChar *)"DwgEntity", NULL)
+#define newXMLProp(name, buf)                                                 \
+  xmlNewProp (node, (const xmlChar *)name, buf);                              \
+  free (buf)
+#define newXMLcProp(name, buf)                                                \
+  xmlNewProp (node, (const xmlChar *)name, (xmlChar *)(buf))
+#define newXMLEntity(rootnode)                                                \
+  xmlNewChild (rootnode, NULL, (const xmlChar *)"DwgEntity", NULL)
 
 /*
- * Creates some of the common attributes, luckily we don't have to care about the order.
+ * Creates some of the common attributes, luckily we don't have to care about
+ * the order.
  * @params xmlNodePtr node       The XML DwgEntity node
  * @params const Dwg_Object *obj The DWG object
  * @return none
@@ -83,7 +87,7 @@ common_entity_attrs (xmlNodePtr node, const Dwg_Object *obj)
   char *name;
   Dwg_Object_Entity *ent = obj->tio.entity;
 
-  //EntityTransparency, ObjectID, ObjectID32, Visible
+  // EntityTransparency, ObjectID, ObjectID32, Visible
 
   buf = doubletohex (obj->handle.value);
   newXMLProp ("Handle", buf);
@@ -91,29 +95,29 @@ common_entity_attrs (xmlNodePtr node, const Dwg_Object *obj)
   buf = ent->xdicobjhandle ? (xmlChar *)"1" : (xmlChar *)"0";
   newXMLcProp ("HasExtensionDictionary", buf);
 
-  //Always return the default "0"
-  name = dwg_ent_get_layer_name(ent, &error);
+  // Always return the default "0"
+  name = dwg_ent_get_layer_name (ent, &error);
   if (!error)
-    newXMLcProp ("Layer", name); //leaks r2007+
+    newXMLcProp ("Layer", name); // leaks r2007+
 
-  //Always return the default: ByLayer
-  name = dwg_ref_get_table_name(ent->ltype, &error);
+  // Always return the default: ByLayer
+  name = dwg_ref_get_table_name (ent->ltype, &error);
   if (!error)
-    newXMLcProp ("Linetype", name); //leaks r2007+
+    newXMLcProp ("Linetype", name); // leaks r2007+
 
   buf = doubletochar (ent->linetype_scale);
   newXMLProp ("LinetypeScale", buf);
 
-  buf = doubletochar (ent->lineweight);
+  buf = inttochar (dxf_cvt_lweight (ent->linewt));
   newXMLProp ("Lineweight", buf);
 
-  name = dwg_ref_get_table_name(ent->material, &error);
+  name = dwg_ref_get_table_name (ent->material, &error);
   if (!error)
-    newXMLcProp ("Material", name); //leaks r2007+
+    newXMLcProp ("Material", name); // leaks r2007+
 
-  name = dwg_ref_get_table_name(ent->plotstyle, &error);
+  name = dwg_ref_get_table_name (ent->plotstyle, &error);
   if (!error)
-    newXMLcProp ("PlotStyleName", name); //leaks r2007+
+    newXMLcProp ("PlotStyleName", name); // leaks r2007+
 }
 
 /*
@@ -170,7 +174,8 @@ add_circle (xmlNodePtr rootnode, const Dwg_Object *obj)
 }
 
 /*
- * This function is emits all hypothetical helix/spring attributes in the XML file
+ * This function is emits all hypothetical helix/spring attributes in the XML
+ * file
  * @params xmlNodePtr rootnode The root node of the XML Document
  * @param const Dwg_Object *obj The DWG Object
  */
@@ -226,36 +231,38 @@ add_helix (xmlNodePtr rootnode, const Dwg_Object *obj)
  * @params Dwg_Object The DWG Object
  */
 void
-add_lwpolyline (xmlNodePtr rootnode, const Dwg_Object* obj)
+add_lwpolyline (xmlNodePtr rootnode, const Dwg_Object *obj)
 {
   Dwg_Entity_LWPOLYLINE *lwpline = obj->tio.entity->tio.LWPOLYLINE;
   int error;
-  BITCODE_RL j, numpts = dwg_ent_lwpline_get_numpoints(lwpline, &error);
-  dwg_point_2d *pts = dwg_ent_lwpline_get_points(lwpline, &error);
+  BITCODE_RL j, numpts = dwg_ent_lwpline_get_numpoints (lwpline, &error);
+  dwg_point_2d *pts = dwg_ent_lwpline_get_points (lwpline, &error);
   xmlChar *buf = NULL;
   xmlNodePtr node = newXMLEntity (rootnode);
 
   newXMLcProp ("type", "IAcadLWPolyline");
-  newXMLcProp ("desc", "IAcadLWPolyline: AutoCAD Lightweight Polyline Interface");
+  newXMLcProp ("desc",
+               "IAcadLWPolyline: AutoCAD Lightweight Polyline Interface");
 
-  //flag?
+  // flag?
   newXMLcProp ("Closed", "0");
-  //ConstantWidth="0.0"
+  // ConstantWidth="0.0"
 
   if (numpts >= 3)
     {
-      buf = malloc(80);
-      sprintf ((char*)buf, "(%.4f %.4f %.4f %.4f %.4f %.4f ... )",
-               pts[0].x, pts[0].y, pts[1].x, pts[1].y, pts[2].x, pts[2].y);
+      buf = malloc (80);
+      sprintf ((char *)buf, "(%.4f %.4f %.4f %.4f %.4f %.4f ... )", pts[0].x,
+               pts[0].y, pts[1].x, pts[1].y, pts[2].x, pts[2].y);
       newXMLProp ("Coordinates", buf);
-      free(buf);
+      free (buf);
     }
-  free(pts);
+  free (pts);
 
   buf = doubletochar (lwpline->elevation);
   newXMLProp ("Elevation", buf);
 
-  buf = spointprepare (lwpline->extrusion.x, lwpline->extrusion.y, lwpline->extrusion.z);
+  buf = spointprepare (lwpline->extrusion.x, lwpline->extrusion.y,
+                       lwpline->extrusion.z);
   newXMLProp ("Extrusion", buf);
 
   newXMLcProp ("ObjectName", "AcDbPolyline");
@@ -273,31 +280,31 @@ add_lwpolyline (xmlNodePtr rootnode, const Dwg_Object* obj)
  * @params Dwg_Object The DWG Object
  */
 void
-add_2dpolyline (xmlNodePtr rootnode, const Dwg_Object* obj)
+add_2dpolyline (xmlNodePtr rootnode, const Dwg_Object *obj)
 {
-  //Dwg_Entity_POLYLINE_2D *polyline2d = obj->tio.entity->tio.POLYLINE_2D;
+  // Dwg_Entity_POLYLINE_2D *polyline2d = obj->tio.entity->tio.POLYLINE_2D;
   int error;
-  BITCODE_RL j, numpts = dwg_object_polyline_2d_get_numpoints(obj, &error);
-  dwg_point_2d *pts = dwg_object_polyline_2d_get_points(obj, &error);
+  BITCODE_RL j, numpts = dwg_object_polyline_2d_get_numpoints (obj, &error);
+  dwg_point_2d *pts = dwg_object_polyline_2d_get_points (obj, &error);
   xmlChar *buf = NULL;
 
-  //the start of the entity
+  // the start of the entity
   xmlNodePtr node = newXMLEntity (rootnode);
 
   newXMLcProp ("type", "IAcad2DPolyline");
   newXMLcProp ("desc", "IAcad2DPolyline: AutoCAD 2dPolyline Interface");
 
-  //flag?
+  // flag?
   newXMLcProp ("Closed", "0");
 
   if (numpts >= 3)
     {
-      buf = malloc(80);
-      sprintf ((char*)buf, "(%.4f %.4f %.4f %.4f %.4f %.4f ... )",
-               pts[0].x, pts[0].y, pts[1].x, pts[1].y, pts[2].x, pts[2].y);
+      buf = malloc (80);
+      sprintf ((char *)buf, "(%.4f %.4f %.4f %.4f %.4f %.4f ... )", pts[0].x,
+               pts[0].y, pts[1].x, pts[1].y, pts[2].x, pts[2].y);
       newXMLProp ("Coordinates", buf);
     }
-  free(pts);
+  free (pts);
 
   common_entity_attrs (node, obj);
   xmlAddChild (rootnode, node);
@@ -311,29 +318,29 @@ add_2dpolyline (xmlNodePtr rootnode, const Dwg_Object* obj)
  * @params Dwg_Object The DWG Object
  */
 void
-add_3dpolyline (xmlNodePtr rootnode, const Dwg_Object* obj)
+add_3dpolyline (xmlNodePtr rootnode, const Dwg_Object *obj)
 {
-  //Dwg_Entity_POLYLINE_3D *polyline3d = obj->tio.entity->tio.POLYLINE_3D;
+  // Dwg_Entity_POLYLINE_3D *polyline3d = obj->tio.entity->tio.POLYLINE_3D;
   int error;
-  BITCODE_RL j, numpts = dwg_object_polyline_3d_get_numpoints(obj, &error);
-  dwg_point_3d *pts = dwg_object_polyline_3d_get_points(obj, &error);
+  BITCODE_RL j, numpts = dwg_object_polyline_3d_get_numpoints (obj, &error);
+  dwg_point_3d *pts = dwg_object_polyline_3d_get_points (obj, &error);
   xmlChar *buf = NULL;
   xmlNodePtr node = newXMLEntity (rootnode);
 
   newXMLcProp ("type", "IAcad3DPolyline");
   newXMLcProp ("desc", "IAcad3DPolyline: AutoCAD 3dPolyline Interface");
 
-  //flag?
+  // flag?
   newXMLcProp ("Closed", "0");
 
   if (numpts >= 2)
     {
-      buf = malloc(80);
-      sprintf ((char*)buf, "(%.4f %.4f %.4f %.4f %.4f %.4f ... )",
-               pts[0].x, pts[0].y, pts[0].z, pts[1].x, pts[1].y, pts[1].z);
+      buf = malloc (80);
+      sprintf ((char *)buf, "(%.4f %.4f %.4f %.4f %.4f %.4f ... )", pts[0].x,
+               pts[0].y, pts[0].z, pts[1].x, pts[1].y, pts[1].z);
       newXMLProp ("Coordinates", buf);
     }
-  free(pts);
+  free (pts);
 
   common_entity_attrs (node, obj);
   newXMLcProp ("ObjectName", "Acad3DPolyline");
@@ -351,7 +358,7 @@ add_arc (xmlNodePtr rootnode, const Dwg_Object *obj)
   Dwg_Entity_ARC *arc = obj->tio.entity->tio.ARC;
   xmlChar *buf, *dtostring;
 
-  //the start of the entity
+  // the start of the entity
   xmlNodePtr node = newXMLEntity (rootnode);
 
   newXMLcProp ("type", "IAcadArc");
@@ -410,9 +417,11 @@ add_insert (xmlNodePtr rootnode, const Dwg_Object *obj)
   int error;
 
   newXMLcProp ("type", "IAcadBlockReference");
-  newXMLcProp ("desc", "IAcadBlockReference: AutoCAD Block Reference Interface");
+  newXMLcProp ("desc",
+               "IAcadBlockReference: AutoCAD Block Reference Interface");
 
-  newXMLcProp ("EffectiveName", dwg_ref_get_table_name(block->block_header, &error));
+  newXMLcProp ("EffectiveName",
+               dwg_ref_get_table_name (block->block_header, &error));
 
   buf = spointprepare (block->ins_pt.x, block->ins_pt.y, block->ins_pt.z);
   newXMLProp ("BasePoint", buf);
@@ -439,11 +448,12 @@ add_ellipse (xmlNodePtr rootnode, const Dwg_Object *obj)
   xmlNodePtr node = newXMLEntity (rootnode);
   xmlChar *buf, *dtostring;
 
-  //Now the attributes
+  // Now the attributes
   newXMLcProp ("type", "IAcadEllipse");
   newXMLcProp ("desc", "IAcadEllipse: AutoCAD Ellipse Interface");
 
-  buf = spointprepare (ellipse->center.x, ellipse->center.y, ellipse->center.z);
+  buf = spointprepare (ellipse->center.x, ellipse->center.y,
+                       ellipse->center.z);
   newXMLProp ("Center", buf);
 
   dtostring = doubletochar (ellipse->end_angle);
@@ -452,7 +462,7 @@ add_ellipse (xmlNodePtr rootnode, const Dwg_Object *obj)
   dtostring = doubletochar (ellipse->start_angle);
   newXMLProp ("StartAngle", dtostring);
 
-  //Axis Ratio and Sm Axis
+  // Axis Ratio and Sm Axis
 
   common_entity_attrs (node, obj);
   xmlAddChild (rootnode, node);
@@ -476,11 +486,14 @@ add_mline (xmlNodePtr rootnode, const Dwg_Object *obj)
 
   if (mline->num_verts >= 3)
     {
-      buf = malloc(80);
-      sprintf ((char*)buf, "(%.4f %.4f %.4f %.4f %.4f %.4f %.4f %.4f %.4f ... )",
-        mline->verts[0].vertex.x, mline->verts[0].vertex.y, mline->verts[0].vertex.z,
-        mline->verts[1].vertex.x, mline->verts[1].vertex.y, mline->verts[1].vertex.z,
-        mline->verts[2].vertex.x, mline->verts[2].vertex.y, mline->verts[2].vertex.z);
+      buf = malloc (80);
+      sprintf ((char *)buf,
+               "(%.4f %.4f %.4f %.4f %.4f %.4f %.4f %.4f %.4f ... )",
+               mline->verts[0].vertex.x, mline->verts[0].vertex.y,
+               mline->verts[0].vertex.z, mline->verts[1].vertex.x,
+               mline->verts[1].vertex.y, mline->verts[1].vertex.z,
+               mline->verts[2].vertex.x, mline->verts[2].vertex.y,
+               mline->verts[2].vertex.z);
       newXMLProp ("Coordinates", buf);
     }
 
@@ -596,16 +609,16 @@ add_spline (xmlNodePtr rootnode, const Dwg_Object *obj)
   newXMLProp ("Degree", dtostring);
 
   buf = spointprepare (spline->end_tan_vec.x, spline->end_tan_vec.y,
-                                spline->end_tan_vec.z);
+                       spline->end_tan_vec.z);
   newXMLProp ("EndTangent", buf);
 
   dtostring = doubletochar (spline->fit_tol);
   newXMLProp ("FitTolerance", dtostring);
 
-  //This is for fit points. DO this too
+  // This is for fit points. DO this too
 
   // @TODO this is an array. Use it properly
-  //fprintf(file, (const xmlChar *)"ControlPoints='(%f %f %f %f)' ", );
+  // fprintf(file, (const xmlChar *)"ControlPoints='(%f %f %f %f)' ", );
 
   common_entity_attrs (node, obj);
   xmlAddChild (rootnode, node);
@@ -623,8 +636,8 @@ add_text (xmlNodePtr rootnode, const Dwg_Object *obj)
   xmlChar *buf, *dtostring;
   xmlNodePtr node = newXMLEntity (rootnode);
 
-  newXMLcProp ("type", "IAcadMText");
-  newXMLcProp ("desc", "IAcadMText: AutoCAD MText Interface");
+  newXMLcProp ("type", "IAcadText");
+  newXMLcProp ("desc", "IAcadText: AutoCAD Text Interface");
 
   dtostring = doubletochar (text->height);
   newXMLProp ("Height", dtostring);
@@ -632,7 +645,7 @@ add_text (xmlNodePtr rootnode, const Dwg_Object *obj)
   buf = spointprepare2 (text->insertion_pt.x, text->insertion_pt.y);
   newXMLProp ("InsertionPoint", buf);
 
-  newXMLcProp ("TextString", (xmlChar*)text->text_value);
+  newXMLcProp ("TextString", (xmlChar *)text->text_value);
 
   dtostring = doubletochar (text->width_factor);
   newXMLProp ("Width", dtostring);
@@ -681,13 +694,13 @@ load_dwg (char *dwgfilename, xmlNodePtr rootnode)
 
   dwg.num_objects = 0;
 
-  //Read the DWG file
-  dwg.opts = 0; //silently
+  // Read the DWG file
+  dwg.opts = 0; // silently
   error = dwg_read_file (dwgfilename, &dwg);
   if (error)
     return error;
 
-  //Emit some entities/objects to the XML file
+  // Emit some entities/objects to the XML file
   for (i = 0; i < dwg.num_objects; i++)
     {
       const Dwg_Object *obj = &dwg.object[i];
@@ -714,11 +727,11 @@ load_dwg (char *dwgfilename, xmlNodePtr rootnode)
           break;
 
         case DWG_TYPE_BLOCK:
-          add_block(rootnode, obj);
+          add_block (rootnode, obj);
           break;
 
         case DWG_TYPE_INSERT:
-          add_insert(rootnode, obj);
+          add_insert (rootnode, obj);
           break;
 
         case DWG_TYPE_MLINE:
@@ -737,9 +750,9 @@ load_dwg (char *dwgfilename, xmlNodePtr rootnode)
           add_ray (rootnode, obj);
           break;
 
-        /*case DWG_TYPE_HELIX:
-          add_helix (rootnode, obj);
-          break;*/
+          /*case DWG_TYPE_HELIX:
+            add_helix (rootnode, obj);
+            break;*/
 
         case DWG_TYPE_TEXT:
           add_text (rootnode, obj);
@@ -753,23 +766,23 @@ load_dwg (char *dwgfilename, xmlNodePtr rootnode)
           add_xline (rootnode, obj);
           break;
 
-/*      case DWG_TYPE_TABLE:
-          add_table(rootnode, obj);
-          break;*/
+          /*      case DWG_TYPE_TABLE:
+                    add_table(rootnode, obj);
+                    break;*/
 
         default:
           if (obj->type < 500 || (obj->type - 500) >= dwg.num_classes)
             break;
           if (!obj->dxfname || obj->supertype == DWG_SUPERTYPE_UNKNOWN)
-              break;
-          if (!strcmp(obj->dxfname, "HELIX"))
-            add_helix(rootnode, obj);
+            break;
+          if (!strcmp (obj->dxfname, "HELIX"))
+            add_helix (rootnode, obj);
 
           break;
         }
     }
 
-  //free the dwg
+  // free the dwg
   dwg_free (&dwg);
   return error;
 }
@@ -777,27 +790,27 @@ load_dwg (char *dwgfilename, xmlNodePtr rootnode)
 int
 main (int argc, char *argv[])
 {
-  //Basic Root Entity
-  char * xml = (char *)"<DwgData></DwgData>";
+  // Basic Root Entity
+  char *xml = (char *)"<DwgData></DwgData>";
   xmlDocPtr doc;
   xmlNodePtr root;
   int error;
 
-  //Check if we have the filename
+  // Check if we have the filename
   REQUIRE_INPUT_FILE_ARG (argc);
 
-  //Load the XML interface
+  // Load the XML interface
   LIBXML_TEST_VERSION
 
-  doc = xmlParseMemory (xml, xmlStrlen ((xmlChar*)xml));
-  //Check if it was able to read it
+  doc = xmlParseMemory (xml, xmlStrlen ((xmlChar *)xml));
+  // Check if it was able to read it
   if (doc == NULL)
     {
       printf ("xmlDoc Creation Failed. Please Check;\n");
       return 1;
     }
 
-  //We have xml loaded. Now get handle to root node
+  // We have xml loaded. Now get handle to root node
   root = xmlDocGetRootElement (doc);
 
   if (root == NULL)
@@ -806,15 +819,16 @@ main (int argc, char *argv[])
       return 1;
     }
 
-  //Load the DWG file
+  // Load the DWG file
   error = load_dwg (argv[1], root);
-  if (error) {
-    xmlFreeDoc (doc);
-    xmlCleanupParser ();
-    return error;
-  }
+  if (error)
+    {
+      xmlFreeDoc (doc);
+      xmlCleanupParser ();
+      return error;
+    }
 
-  //Save the XML and Cleanup
+  // Save the XML and Cleanup
   xmlSaveFormatFileEnc (argv[2], doc, "UTF-8", 1);
   xmlFreeDoc (doc);
   xmlCleanupParser ();
